@@ -1,7 +1,8 @@
 from nonebot.adapters.kaiheila import Bot, Event
-from nonebot.permission import SuperUser
+from nonebot.adapters.kaiheila.event import ChannelMessageEvent, PrivateMessageEvent
 
 from nonebot_plugin_access_control.subject import SubjectExtractor
+from nonebot_plugin_access_control.utils.superuser import is_superuser
 
 
 class KaiheilaSubjectExtractor(SubjectExtractor[Bot, Event]):
@@ -20,7 +21,7 @@ class KaiheilaSubjectExtractor(SubjectExtractor[Bot, Event]):
         user_id = getattr(event, "user_id", None)
         if user_id is not None:
             li.append(f"kaiheila:{user_id}")
-            if await SuperUser()(bot, event):
+            if is_superuser(bot, event):
                 li.append("superuser")
 
         channel_id = getattr(event, "group_id", None)
@@ -30,6 +31,11 @@ class KaiheilaSubjectExtractor(SubjectExtractor[Bot, Event]):
         if event.extra.guild_id is not None:
             li.append(f"kaiheila:g{event.extra.guild_id}")
 
+        if isinstance(event, ChannelMessageEvent):
+            li.append("kaiheila:channel")
+        elif isinstance(event, PrivateMessageEvent):
+            li.append("kaiheila:private")
+
         li.append("kaiheila")
         li.append("all")
 
